aboutsummaryrefslogtreecommitdiff
path: root/Week9/src/com/camilstaps/shop/Article.java
diff options
context:
space:
mode:
Diffstat (limited to 'Week9/src/com/camilstaps/shop/Article.java')
-rw-r--r--Week9/src/com/camilstaps/shop/Article.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/Week9/src/com/camilstaps/shop/Article.java b/Week9/src/com/camilstaps/shop/Article.java
index 92b496f..d22a323 100644
--- a/Week9/src/com/camilstaps/shop/Article.java
+++ b/Week9/src/com/camilstaps/shop/Article.java
@@ -23,9 +23,9 @@ public class Article extends DatabaseItem {
private final float price;
/**
* The user who added the article
*/
- private final User user;
+ private final User owner;
/**
* Straightforwardly creating a new article
@@ -35,14 +35,14 @@ public class Article extends DatabaseItem {
* @param price
*/
public Article(User user, String name, Category category, float price) {
- this.user = user;
+ this.owner = user;
this.name = name;
this.category = category;
this.price = price;
}
- public User getUser() {
- return user;
+ public User getOwner() {
+ return owner;
}
public String getName() {
@@ -23,9 +23,9 @@ public class Article extends DatabaseItem {
private final float price;
/**
- * The user who added the article
+ * The owner who added the article
*/